@@ -1,42 +1,44 @@
 //! XRPL Hooks API
 //!
+//! This crate allows you to write XRPL hooks in Rust.
+//!
+//! Before you begin, it is highly recommended that you read
+//! the [official docs](https://xrpl-hooks.readme.io/) carefully.
+//!
 //! # Examples
 //!
-//! See <https://github.com/otov4its/xrpl-hook-template/>
+//! For a quick start and to view examples,
+//! use the [hook template](https://github.com/otov4its/xrpl-hook-template/)
 
 #![no_std]
 #![deny(
     warnings,
     clippy::all,
     missing_copy_implementations,
-    //todo missing_docs,
+    missing_docs,
     rustdoc::missing_crate_level_docs,
     rustdoc::missing_doc_code_examples,
     non_ascii_idents,
     unreachable_pub
 )]
 #![doc(test(attr(deny(warnings))))]
-#![doc(html_root_url = "https://docs.rs/xrpl-hooks/0.1.0")]
+#![doc(html_root_url = "https://docs.rs/xrpl-hooks/0.2.0")]
+
+mod macros;
 
 /// # Low-level unsafe C bindings
 ///
 /// Use very carefully if at all necessary.
 pub mod _c;
 
-/// Error handling
-pub mod error;
-
 /// XRPL Hooks API
 pub mod api;
 
 /// A few utilities
 pub mod helpers;
 
-/// Usefull macros to comply XRPL Hooks
-pub mod macros;
-
 // Prelude
-pub use {api::*, error::*, helpers::*, macros::*};
+pub use {api::*, helpers::*};
 
 #[cfg(not(test))]
 use core::panic::PanicInfo;
